@@ -1,4 +1,4 @@
-use super::ParseErr;
+use super::errors::ParseErr;
 use num_cpus;
 /// Receives an input that is either an integer, or percent. If the string ends with `%`, it will
 /// be calculated as a percent of the total number of CPU cores. Otherwise, the number provided
@@ -18,16 +18,8 @@ pub fn parse(value: &str) -> Result<usize, ParseErr> {
 #[test]
 fn test_parse() {
     let ncores = num_cpus::get();
-    let value1 = "50%";
-    let value2 = "100%";
-    let value3 = "150%";
-    let value4 = "4";
-    let expected1 = (ncores * 50) / 100;
-    let expected2 = (ncores * 100) / 100;
-    let expected3 = (ncores * 150) / 100;
-    let expected4 = 4;
-    assert_eq!(Ok(expected1), parse(value1));
-    assert_eq!(Ok(expected2), parse(value2));
-    assert_eq!(Ok(expected3), parse(value3));
-    assert_eq!(Ok(expected4), parse(value4));
+    assert_eq!((ncores * 50) / 100,  parse("50%" ).unwrap());
+    assert_eq!((ncores * 100) / 100, parse("100%").unwrap());
+    assert_eq!((ncores * 150) / 100, parse("150%").unwrap());
+    assert_eq!(4,                    parse("4"   ).unwrap());
 }
