@@ -1,13 +1,29 @@
-use std::env;
 use std::ffi::OsStr;
 use std::io::{self, Write};
 use std::process::{Child, Command, Stdio};
 use super::tokenizer::*;
+use super::arguments;
 
 pub enum CommandErr {
     IO(io::Error)
 }
 
+/// If no placeholder tokens are in use, then the input will be appended at the end of the the command.
+fn append_argument(arguments: &mut String, command_template: &[Token], input: &str) {
+    // Check to see if any placeholder tokens are in use.
+    let placeholder_exists = command_template.iter().any(|x| {
+        x == &Token::BaseAndExt || x == &Token::Basename || x == &Token::Dirname ||
+        x == &Token::Job || x == &Token::Placeholder || x == &Token::RemoveExtension ||
+        x == &Token::Slot
+    });
+
+    // If no placeholder tokens are in use, the user probably wants to infer one.
+    if !placeholder_exists {
+        arguments.push(' ');
+        arguments.push_str(input);
+    }
+}
+
 pub struct ParallelCommand<'a> {
     pub slot_no:          &'a str,
     pub job_no:           &'a str,
@@ -17,28 +33,16 @@ pub struct ParallelCommand<'a> {
 }
 
 impl<'a> ParallelCommand<'a> {
-    pub fn exec(&self, pipe: bool, uses_shell: bool, quiet: bool) -> Result<Child, CommandErr> {
+    pub fn exec(&self, flags: u8) -> Result<Child, CommandErr> {
         // First the arguments will be generated based on the tokens and input.
         let mut arguments = String::with_capacity(self.command_template.len() << 1);
-        self.build_arguments(&mut arguments, pipe);
+        self.build_arguments(&mut arguments, flags & arguments::PIPE_IS_ENABLED != 0);
 
-        if !pipe {
-            // Check to see if any placeholder tokens are in use.
-            let placeholder_exists = self.command_template.iter().any(|x| {
-                x == &Token::BaseAndExt || x == &Token::Basename || x == &Token::Dirname ||
-                x == &Token::Job || x == &Token::Placeholder || x == &Token::RemoveExtension ||
-                x == &Token::Slot
-            });
-
-            // If no placeholder tokens are in use, the user probably wants to infer one.
-            if !placeholder_exists {
-                arguments.push(' ');
-                arguments.push_str(self.input);
-            }
-
-            get_command_output(&arguments, pipe, uses_shell, quiet).map_err(CommandErr::IO)
+        if flags & arguments::PIPE_IS_ENABLED == 0 {
+            append_argument(&mut arguments, self.command_template, self.input);
+            get_command_output(&arguments, flags).map_err(CommandErr::IO)
         } else {
-            let mut child = get_command_output(&arguments, pipe, uses_shell, quiet).map_err(CommandErr::IO)?;
+            let mut child = get_command_output(&arguments, flags).map_err(CommandErr::IO)?;
 
             {   // Grab a handle to the child's stdin and write the input argument to the child's stdin.
                 let stdin = child.stdin.as_mut().unwrap();
@@ -68,26 +72,26 @@ impl<'a> ParallelCommand<'a> {
         } else {
             for arg in self.command_template {
                 match *arg {
-                    Token::Argument(ref arg)  => arguments.push_str(arg),
-                    Token::Basename           => arguments.push_str(basename(self.input)),
-                    Token::BaseAndExt         => arguments.push_str(basename(remove_extension(self.input))),
-                    Token::Dirname            => arguments.push_str(dirname(self.input)),
-                    Token::Job                => arguments.push_str(self.job_no),
-                    Token::Placeholder        => arguments.push_str(self.input),
-                    Token::RemoveExtension    => arguments.push_str(remove_extension(self.input)),
-                    Token::Slot               => arguments.push_str(self.slot_no)
+                    Token::Argument(ref arg) => arguments.push_str(arg),
+                    Token::Basename          => arguments.push_str(basename(self.input)),
+                    Token::BaseAndExt        => arguments.push_str(basename(remove_extension(self.input))),
+                    Token::Dirname           => arguments.push_str(dirname(self.input)),
+                    Token::Job               => arguments.push_str(self.job_no),
+                    Token::Placeholder       => arguments.push_str(self.input),
+                    Token::RemoveExtension   => arguments.push_str(remove_extension(self.input)),
+                    Token::Slot              => arguments.push_str(self.slot_no)
                 }
             }
         }
     }
 }
 
-pub fn get_command_output(command: &str, pipe: bool, uses_shell: bool, quiet: bool) -> io::Result<Child> {
-    if uses_shell && !pipe {
-        shell_output(command, quiet, pipe)
+pub fn get_command_output(command: &str, flags: u8) -> io::Result<Child> {
+    if flags & arguments::SHELL_ENABLED != 0 && flags & arguments::PIPE_IS_ENABLED == 0 {
+        shell_output(command, flags)
     } else {
         let arguments = split_into_args(command);
-        match (arguments.len() == 1, quiet, pipe) {
+        match (arguments.len() == 1, flags & arguments::QUIET_MODE != 0, flags & arguments::PIPE_IS_ENABLED != 0) {
             (true, true, false) => Command::new(&arguments[0])
                 .stdout(Stdio::null()).stderr(Stdio::piped())
                 .spawn(),
@@ -116,14 +120,16 @@ pub fn get_command_output(command: &str, pipe: bool, uses_shell: bool, quiet: bo
     }
 }
 
-fn shell_output<S: AsRef<OsStr>>(args: S, quiet: bool, pipe: bool) -> io::Result<Child> {
+fn shell_output<S: AsRef<OsStr>>(args: S, flags: u8) -> io::Result<Child> {
     let (cmd, flag) = if cfg!(windows) {
         ("cmd".to_owned(), "/C")
+    } else if flags & arguments::DASH_EXISTS != 0  {
+        ("dash".to_owned(), "-c")
     } else {
-        (env::var("SHELL").unwrap_or("sh".to_owned()), "-c")
+        ("sh".to_owned(), "-c")
     };
 
-    match (quiet, pipe) {
+    match (flags & arguments::QUIET_MODE != 0, flags & arguments::PIPE_IS_ENABLED != 0) {
         (true, false) => Command::new(cmd).arg(flag).arg(args)
             .stdout(Stdio::null()).stderr(Stdio::piped())
             .spawn(),
@@ -217,6 +223,7 @@ fn split_into_args(command: &str) -> Vec<String> {
     }
 
     if !buffer.is_empty() { output.push(buffer); }
+    output.shrink_to_fit();
     output
 }
 
