@@ -1,5 +1,6 @@
 extern crate num_cpus;
 extern crate permutate;
+
 mod arguments;
 mod command;
 mod disk_buffer;
@@ -39,32 +40,42 @@ fn main() {
     // Will contain handles to the upcoming threads to know when the threads are finished.
     let mut threads = Vec::with_capacity(args.ncores);
 
-    if args.flags.verbose {
+    if args.flags & arguments::VERBOSE_MODE != 0 {
         verbose::total_inputs(&stdout, args.ncores, args.ninputs);
     }
 
     // The `slot` variable is required by the {%} token.
-    for slot in 1..args.ncores+1 {
-        let num_inputs = args.ninputs;
-        let inputs     = shared_input.clone();
-        let flags      = args.flags.clone();
-        let output_tx  = output_tx.clone();
+    if args.flags & arguments::INPUTS_ARE_COMMANDS != 0 {
+        for _ in 0..args.ncores {
+            let num_inputs = args.ninputs;
+            let inputs     = shared_input.clone();
+            let flags      = args.flags;
+            let output_tx  = output_tx.clone();
 
-        // Execute the corresponding thread based on input flags.
-        let handle: JoinHandle<()> = if flags.inputs_are_commands {
-            thread::spawn(move || {
+            // Each input will be treated as a command
+            let handle: JoinHandle<()> = thread::spawn(move || {
                 threads::execute::inputs(num_inputs, flags, inputs, output_tx)
-            })
-        } else {
-            let arguments = args.arguments.clone();
-            thread::spawn(move || {
-                threads::execute::command(slot, num_inputs, flags, arguments, inputs,
-                    output_tx)
-            })
-        };
+            });
 
-        // Add the thread handle to the `threads` vector to know when to quit the program.
-        threads.push(handle);
+            // Add the thread handle to the `threads` vector to know when to quit the program.
+            threads.push(handle);
+        }
+    } else {
+        for slot in 1..args.ncores+1 {
+            let num_inputs = args.ninputs;
+            let inputs     = shared_input.clone();
+            let flags      = args.flags;
+            let output_tx  = output_tx.clone();
+            let arguments = args.arguments.clone();
+
+            // The command will be built from the arguments, and inputs will be transferred to the command.
+            let handle: JoinHandle<()> = thread::spawn(move || {
+                threads::execute::command(slot, num_inputs, flags, arguments, inputs, output_tx)
+            });
+
+            // Add the thread handle to the `threads` vector to know when to quit the program.
+            threads.push(handle);
+        }
     }
 
     threads::receive_messages(input_rx, args);
@@ -73,18 +84,16 @@ fn main() {
     // If errors have occurred, re-print these errors at the end.
     if let Some(path) = filepaths::errors() {
         if let Ok(file) = File::open(path) {
-            if let Ok(metadata) = file.metadata() {
-                if metadata.len() > 0 {
-                    let stderr = &mut stderr.lock();
-                    let _ = stderr.write(b"parallel: encountered errors during processing:\n");
-                    for line in BufReader::new(file).lines() {
-                        if let Ok(line) = line {
-                            let _ = stderr.write(line.as_bytes());
-                            let _ = stderr.write(b"\n");
-                        }
+            if file.metadata().ok().map_or(0, |metadata| metadata.len()) > 0 {
+                let stderr = &mut stderr.lock();
+                let _ = stderr.write(b"parallel: encountered errors during processing:\n");
+                for line in BufReader::new(file).lines() {
+                    if let Ok(line) = line {
+                        let _ = stderr.write(line.as_bytes());
+                        let _ = stderr.write(b"\n");
                     }
-                    exit(1);
                 }
+                exit(1);
             }
         }
     }
